package com.ksyun;

import com.ksyun.constant.Consts;
import com.ksyun.model.SendSmsResult;
import com.ksyun.util.UtilAll;
import jodd.http.HttpRequest;
import jodd.http.HttpResponse;

import java.util.HashMap;
import java.util.Map;

public class SmsService {

    private String ak;

    private String sk;

    private String signName;

    public SmsService(String ak, String sk, String signName) {
        if (UtilAll.isNullOrEmpty(ak) || UtilAll.isNullOrEmpty(sk)) {
            throw new IllegalArgumentException("ak或sk不能为空");
        }
        this.ak = ak;
        this.sk = sk;
        this.signName = signName;
    }

    public SendSmsResult sendSms(String mobile, String tplId, Map<String, String> tplParams, String Content, String SmsType) {
        try {
            HttpRequest request = HttpRequest
                .post(Consts.SMS_HOST)
                .accept("application/json")
                .contentType("application/x-www-form-urlencoded;charset=utf8");
            Map<String, String> params = buildSendSmsParams(mobile, tplId, tplParams, Content, SmsType);
            Map<String, String> finalParams = UtilAll.sign(ak, sk, Consts.service, Consts.region, params);
            for (Map.Entry<String, String> entry : finalParams.entrySet()) {
                request.form(entry.getKey(), entry.getValue());
            }

            HttpResponse response = request.send();
            SendSmsResult sendSmsResult = UtilAll.fromJson(response.bodyText(), SendSmsResult.class);
            sendSmsResult.setCode(response.statusCode());
            return sendSmsResult;
        } catch (Exception e) {
            throw new RuntimeException("sensSms Occur Error.", e);
        }
    }



    private Map<String, String> buildSendSmsParams(String mobile, String tplId, Map<String, String> tplParams, String Content, String SmsType) throws Exception {
        Map<String, String> params = new HashMap<String, String>();
        params.put("Action", Consts.Aaction_SendSms);
        params.put("Version", Consts.Version);
        params.put("Mobile", mobile);
        params.put("SignName", this.signName);
        if (!tplId.isEmpty()) {
            params.put("TplId", tplId);
            params.put("TplParams", UtilAll.toJson(tplParams));
        } else {
            params.put("Content", Content);
            params.put("SmsType", SmsType);
        }
        return params;
    }

    private Map<String, String> buildFetchSmsReportParams(Integer pullSize) {
        Integer finalPullSize = (pullSize > 500) ? 500 : pullSize;
        Map<String, String> params = new HashMap<>();
        params.put("Action", Consts.Aaction_PullSmsReport);
        params.put("Version", Consts.Version);
        params.put("Size", String.valueOf(finalPullSize));
        return params;
    }

    public String fetchSmsReport(int pullSize) {
        try {
            HttpRequest request = HttpRequest.get(Consts.SMS_HOST).accept("application/json");
            Map<String, String> params = buildFetchSmsReportParams(pullSize);
            Map<String, String> finalParams = UtilAll.sign(ak, sk, Consts.service, Consts.region, params);
            request.query(finalParams);
            HttpResponse response = request.send();
            return response.bodyText();
        } catch (Exception e) {
            throw new RuntimeException("fetchSmsReport Occur Error.", e);
        }
    }

}
